# Mcdbot

Hello,

This is my personal project for connecting Discord communities with their Minecraft servers.

I'm making this mainly for myself, and so there is no documentation about the features or installation or anything
really.

If you have any questions, please feel free to create an issue in the issue tracker.

--jsmetana, 2020-10-17T17:18:35+02:00
